%global models %{_libdir}/ascend/models
%global checkout 753
%global date 20140724

Name:    freesteam
Summary: Calculate the properties of water and steam
Version: 2.1
Release: 7.%{date}svn%{checkout}%{?dist}
License: GPLv2+
URL:     http://freesteam.sourceforge.net/
Source0: http://sourceforge.net/code-snapshots/svn/f/fr/freesteam/code/freesteam-code-%{checkout}-trunk.zip

Patch0:  %{name}-optflags.patch


#------ build dependencies -------
BuildRequires: scons
BuildRequires: ascend-devel
BuildRequires: blas-devel, libglade2-devel, gsl-devel
BuildRequires: glib2-devel, gtk2-devel
BuildRequires: desktop-file-utils

#------ python2 bindings ---------
BuildRequires: python2-devel
BuildRequires: swig >= 2.0.1

%description
Open source steam property routines in C. 
Implements the IAPWS-IF97 steam tables from the 
International Association for the Properties of Water and Steam. 
Includes two-way property solvers and test suite. 
Can be used from C/C++, Fortran, Python, LabVIEW, Octave and ASCEND.

%package devel
Summary: Freesteam development files
Requires: %{name}%{?_isa} = %{version}-%{release}
%description devel
Freesteam header files, example codes and 
output configuration data application.

%package -n python-freesteam
Summary: Freesteam Python2 bindings
Requires: %{name}%{?_isa} = %{version}-%{release}
%description -n python-freesteam
Language bindings that allow freesteam to be accessed 
from the Python2 scripting language.

%package ascend
Summary: Water/steam properties functions for use with ASCEND
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: ascend-libs%{?_isa}
%description ascend
ASCEND bindings for the freesteam steam tables library. This package allows
IAPWS-IF97 steam tables to be used in ASCEND for modeling of water/steam
equipment models.

%package gtk
Summary: Calculate water and steam properties (GUI)
Requires: %{name}%{?_isa} = %{version}-%{release}
%description gtk
Interactive GUI for freesteam IAPWS steam properties library, allows
quick evaluation of steam properties for a range of specified property
pairs, eg (p,h), (p,T), (p,s), (T,x) etc.

%prep
%setup -q -n %{name}-code-%{checkout}-trunk
cp -p python/README.txt python/README-python.txt

%patch0 -p0
sed -e 's|@@OPTFLAGS@@|%{optflags}|g' -i SConstruct

##Fix instances of #!/usr/bin/env python
sed -e 's|/usr/bin/env python|%{__python2}|g' -i SConstruct
for i in `find . -type f \( -name "SConscript" -o -name "test.py" -o -name "tsp3d.py" \)`; do
 sed -e 's|/usr/bin/env python|%{__python2}|g' -i $i
done

%build
scons %{?_smp_mflags} \
 GSL_CPPPATH=%{_includedir}/gsl \
 GSL_LIBPATH=%{_libdir} \
 LIBPATH=%{_libdir} \
 ASCEND_CPPPATH=%{_includedir}/ascend \
 python ascend

%install
scons INSTALL_ROOT=%{buildroot} \
 INSTALL_PREFIX=%{_prefix} \
 INSTALL_SHARE=%{_datadir} \
 INSTALL_BIN=%{_bindir} \
 INSTALL_INCLUDE=%{_includedir} \
 INSTALL_LIB=%{_libdir} \
 INSTALL_PYTHON=%{python2_sitearch} install

# GTK GUI icon/.desktop file
pushd gtk/gnome
desktop-file-install freesteam-gtk.desktop --dir=%{buildroot}%{_datadir}/applications

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/64x64
install -pm 644 freesteam-gtk-64x64.png %{buildroot}%{_datadir}/icons
install -pm 644 freesteam-gtk-64x64.png %{buildroot}%{_datadir}/icons/hicolor/64x64
popd

install -Dpm 644 man/freesteam-config.man %{buildroot}%{_mandir}/man1/freesteam-config.1
install -Dpm 644 gtk/freesteam-gtk.man %{buildroot}%{_mandir}/man1/freesteam-gtk.1

# Uninstalled Python files
install -Dpm 644 python/freesteam.py %{buildroot}%{python2_sitearch}/
install -Dpm 755 python/_freesteam.so %{buildroot}%{python2_sitearch}/

chmod 0755 %{buildroot}%{_libdir}/lib%{name}.so.*
chmod 0755 %{buildroot}%{models}/libfreesteam_ascend.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n freesteam-gtk
/bin/touch --no-create %{_datadir}/icons &>/dev/null || :

%postun -n freesteam-gtk
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons &>/dev/null || :
fi

%posttrans -n freesteam-gtk
/usr/bin/gtk-update-icon-cache %{_datadir}/icons &>/dev/null || :

%check
scons test 
./test

%files
%doc LICENSE.txt README.txt CHANGELOG.txt
%{_libdir}/libfreesteam.so.*

%files ascend
%doc LICENSE.txt
%{models}/%{name}/
%{models}/libfreesteam_ascend.so

%files devel
%{_bindir}/freesteam-config
%{_libdir}/libfreesteam.so
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/examples
%{_includedir}/%{name}/
%{_mandir}/man1/freesteam-config.1*

%files -n python-freesteam
%doc python/README-python.txt LICENSE.txt
%{python2_sitearch}/_%{name}.so
%{python2_sitearch}/%{name}.py
%{python2_sitearch}/%{name}.py[co]

%files gtk
%{_bindir}/freesteam-gtk
%{_datadir}/icons/freesteam-*.png
%{_datadir}/icons/hicolor/64x64/freesteam-*.png
%{_datadir}/applications/freesteam-gtk.desktop
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/freesteam-gtk.glade
%{_datadir}/%{name}/icon.png
%{_mandir}/man1/freesteam-gtk.1*

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1-7.20140724svn753
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Aug 22 2014 Antonio Trande <sagitter@fedoraproject.org> - 2.1-6.20140724svn753
- freesteam-ascend sub-package requires ascend-libs

* Tue Aug 19 2014 Antonio Trande <sagitter@fedoraproject.org> - 2.1-5.20140724svn753
- freesteam-ascend sub-package requires ascend now

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1-4.20140724svn753
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 22 2014 Antonio Trande <sagitter@fedoraproject.org> 2.1-3.20140724svn753
- New svn release
- Fixed unused-direct-shlib-dependency warnings 

* Tue Jul 22 2014 Antonio Trande <sagitter@fedoraproject.org> 2.1-2
- Fixed Icon Cache scriptlets only for gtk sub-package
- Some manual installation fixes
- Fix instances of #!/usr/bin/env python

* Thu Jul 10 2014 Antonio Trande <sagitter@fedoraproject.org> 2.1-1
- Initial package
